package com.yihu.quota.service.medicalInsurance;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.yihu.ehr.profile.core.ResourceCore;
import com.yihu.ehr.solr.SolrUtil;
import com.yihu.ehr.util.datetime.DateUtil;
import com.yihu.ehr.util.rest.Envelop;
import io.swagger.annotations.ApiParam;
import org.apache.solr.common.SolrDocument;
import org.apache.solr.common.SolrDocumentList;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * @Author: zhengwei
 * @Date: 2018/9/19 20:35
 * @Description:医保相关
 */
@Service
public class MedicalInsuranceService {
    @Autowired
    private SolrUtil solrUtil;
    @Autowired
    private JdbcTemplate jdbcTemplate;
    @Autowired
    private ObjectMapper objectMapper;

    /**
     * 超高费用
     * @param month
     * @param eventType
     * @param hosLevel
     * @param hosHierarchy
     * @param size
     * @param page
     * @return
     * @throws Exception
     */
    public Envelop highCost(String month,String eventType,String hosLevel, String hosHierarchy,int size, int page) throws Exception{
        Envelop result = new Envelop();
        double fee = 0.0;
        String q = "event_type:" + eventType;
        StringBuffer sb = new StringBuffer();
        String start = month+"-01T00:00:00Z";
        String end = DateUtil.getLastDate(month+"-01","yyyy-MM-dd","yyyy-MM-dd")+"T23:59:59Z";
        if("0".equals(eventType)){
            fee=3000;
            sb.append("EHR_000045:[").append(fee).append(" TO *]").append(" AND event_date:[")
                    .append(start).append(" TO ").append(end).append("]");
        }else{
            fee=20000;
            sb.append("EHR_000175:[").append(fee).append(" TO *]").append(" AND event_date:[")
                    .append(start).append(" TO ").append(end).append("]");
        }
        SolrDocumentList sublist = solrUtil.query(ResourceCore.SubTable,q,sb.toString(),null,(page-1)*size,size);
        if(sublist!=null && sublist.getNumFound()>0){
            for (SolrDocument doc : sublist){
                String q1="rowkey:"+doc.getFieldValue("profile_id");
                SolrDocumentList list = solrUtil.query(ResourceCore.MasterTable,q1,null,null,0,1);
                doc.putAll(list.get(0));
            }
        }
        long count = solrUtil.count(ResourceCore.SubTable, q, sb.toString());
        result.setSuccessFlg(true);
        result.setDetailModelList(sublist);
        result.setTotalCount((int)count);
        result.setCurrPage(page);
        result.setPageSize(size);
        if (result.getTotalCount() % result.getPageSize() > 0) {
            result.setTotalPage(result.getTotalCount() / result.getPageSize() + 1);
        } else {
            result.setTotalPage(result.getTotalCount() / result.getPageSize());
        }
        return result;
    }

}
